// Copyright (C) 2006-2013 Xilinx, Inc.  All rights reserved
// $Id: ConstraintsChecker.h,v 1.20.206.2 2013/05/10 00:04:05 jcorbett Exp $
//
// Read a UCF and analyze the locations of area groups, package pins,
// and IO buffers.
//
// R#report_io_assignments, R#check_package_pins, R#check_io_banks

#ifndef Iv_ConstraintsChecker_h
#define Iv_ConstraintsChecker_h

#include <map>
#include <string>
#include <vector>

#include "TUtilities/export/smart_ptr.hpp"

#include "Data.h"
#include "PinGroup.h"
#include "PinGrid.h"
#include "DeviceModel.h"
#include "TileChecker.h"

class Cs_Constraint_Range;
class Cs_ConstraintMgr;
class Cs_Constraint_Locate;
class Xdm_Model;
class Xdm_Design;

class ConstraintsChecker {
public:
   ConstraintsChecker(Data& cadData);
   ~ConstraintsChecker();
   void Check();
   void ReportFaults(TileChecker& tileChecker);
   int GetStatus();

private:
   void LoadUCF();
   void CollectAreaRanges();
   const std::string GetAreaGroupName(Cs_Constraint_Locate* loc);
   const std::string GetAreaGroupName(Cs_Constraint_Range* range);

   void CheckPinLocations();

private:
   Data& data;
   DeviceModel* deviceModel;

   boost::shared_ptr<PinGrid> pinGrid;

   int errorCount;
   Cs_ConstraintMgr* constraintMgr;

   Xdm_Model* xdm;
   Xdm_Design* design;
};

#endif
